@@ -1,22 +1,24 @@
 "capscale" <-
-    function (formula, data, distance = "euclidean", comm = NULL, 
-              add = FALSE, ...) 
+function (formula, data, distance = "euclidean", comm = NULL, 
+    add = FALSE, ...) 
 {
     if (!inherits(formula, "formula")) 
         stop("Needs a model formula")
     if (missing(data)) {
         data <- parent.frame()
+    } else {
+        data <- ordiGetData(match.call(), environment(formula))
     }
-    formula <- formula(terms(formula, data=data))
+    formula <- formula(terms(formula, data = data))
     X <- formula[[2]]
-    X <- eval(X)
+    X <- eval(X, environment(formula))
     if (!inherits(X, "dist")) {
         comm <- X
         X <- vegdist(X, method = distance)
     }
     inertia <- attr(X, "method")
     inertia <- paste(toupper(substr(inertia, 1, 1)), substr(inertia, 
-                                                            2, 256), sep = "")
+        2, 256), sep = "")
     inertia <- paste("squared", inertia, "distance")
     if (add) 
         inertia <- paste(inertia, "(euclidified)")
@@ -36,16 +38,17 @@
     neig <- min(which(X$eig < 0) - 1, k)
     sol <- X$points[, 1:neig]
     fla <- update(formula, sol ~ .)
+    environment(fla) <- environment()
     d <- ordiParseFormula(fla, data)
     sol <- rda.default(d$X, d$Y, d$Z, ...)
     sol$tot.chi <- sol$tot.chi
     if (!is.null(sol$CCA)) {
         colnames(sol$CCA$u) <- colnames(sol$CCA$biplot) <- names(sol$CCA$eig) <- colnames(sol$CCA$wa) <- colnames(sol$CCA$v) <- paste("CAP", 
-                                                                                                                                      1:ncol(sol$CCA$u), sep = "")
+            1:ncol(sol$CCA$u), sep = "")
     }
     if (!is.null(sol$CA)) {
         colnames(sol$CA$u) <- names(sol$CA$eig) <- colnames(sol$CA$v) <- paste("MDS", 
-                                                                               1:ncol(sol$CA$u), sep = "")
+            1:ncol(sol$CA$u), sep = "")
     }
     if (!is.null(comm)) {
         comm <- scale(comm, center = TRUE, scale = FALSE)
@@ -54,13 +57,13 @@
         if (!is.null(sol$CCA)) {
             sol$CCA$v.eig <- t(comm) %*% sol$CCA$u/sqrt(k)
             sol$CCA$v <- sweep(sol$CCA$v.eig, 2, sqrt(sol$CCA$eig), 
-                               "/")
+                "/")
             comm <- qr.resid(sol$CCA$QR, comm)
         }
         if (!is.null(sol$CA)) {
             sol$CA$v.eig <- t(comm) %*% sol$CA$u/sqrt(k)
             sol$CA$v <- sweep(sol$CA$v.eig, 2, sqrt(sol$CA$eig), 
-                              "/")
+                "/")
         }
     }
     if (!is.null(sol$CCA)) 
@@ -70,7 +73,7 @@
     if (!is.null(sol$CCA$centroids)) {
         rs <- rowSums(sol$CCA$centroids^2)
         sol$CCA$centroids <- sol$CCA$centroids[rs > 1e-04, , 
-                                               drop = FALSE]
+            drop = FALSE]
     }
     sol$call <- match.call()
     sol$terms <- terms(formula, "Condition", data = data)
@@ -82,3 +85,4 @@
     class(sol) <- c("capscale", class(sol))
     sol
 }
+
