@@ -1,10 +1,10 @@
 "ordiParseFormula" <-
-    function (formula, data, xlev = NULL) 
+function (formula, data, xlev = NULL) 
 {
     Terms <- terms(formula, "Condition", data = data)
     flapart <- fla <- formula <- formula(Terms, width.cutoff = 500)
     specdata <- formula[[2]]
-    X <- eval(specdata, data, parent.frame())
+    X <- eval(specdata, data, environment(formula))
     X <- as.matrix(X)
     indPartial <- attr(Terms, "specials")$Condition
     mf <- Z <- NULL
@@ -15,15 +15,15 @@
         P.formula <- as.formula(paste("~", Pterm))
         zlev <- xlev[names(xlev) %in% Pterm]
         mf <- model.frame(P.formula, data, na.action = na.fail, 
-                          xlev = zlev)
+            xlev = zlev)
         Z <- model.matrix(P.formula, mf)
         if (any(colnames(Z) == "(Intercept)")) {
             xint <- which(colnames(Z) == "(Intercept)")
             Z <- Z[, -xint, drop = FALSE]
         }
         partterm <- sapply(partterm, function(x) deparse(x))
-        formula <- update(formula, paste(".~.-",
-                                         paste(partterm, collapse = "-")))
+        formula <- update(formula, paste(".~.-", paste(partterm, 
+            collapse = "-")))
         flapart <- update(formula, paste(". ~ . +", Pterm))
     }
     formula[[2]] <- NULL
@@ -33,7 +33,7 @@
         if (exists("Pterm")) 
             xlev <- xlev[!(names(xlev) %in% Pterm)]
         mf <- model.frame(formula, data, na.action = na.fail, 
-                          xlev = xlev)
+            xlev = xlev)
         Y <- model.matrix(formula, mf)
         if (any(colnames(Y) == "(Intercept)")) {
             xint <- which(colnames(Y) == "(Intercept)")
@@ -41,5 +41,6 @@
         }
     }
     list(X = X, Y = Y, Z = Z, terms = terms(fla, width.cutoff = 500), 
-         terms.expand = terms(flapart, width.cutoff = 500), modelframe = mf)
+        terms.expand = terms(flapart, width.cutoff = 500), modelframe = mf)
 }
+
